/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DnsResponsePolicyRuleConfig extends cdktf.TerraformMetaArguments {
    /**
    * The DNS name (wildcard or exact) to apply this rule to. Must be unique within the Response Policy Rule.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/dns_response_policy_rule#dns_name DnsResponsePolicyRule#dns_name}
    */
    readonly dnsName: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/dns_response_policy_rule#id DnsResponsePolicyRule#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/dns_response_policy_rule#project DnsResponsePolicyRule#project}
    */
    readonly project?: string;
    /**
    * Identifies the response policy addressed by this request.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/dns_response_policy_rule#response_policy DnsResponsePolicyRule#response_policy}
    */
    readonly responsePolicy: string;
    /**
    * An identifier for this rule. Must be unique with the ResponsePolicy.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/dns_response_policy_rule#rule_name DnsResponsePolicyRule#rule_name}
    */
    readonly ruleName: string;
    /**
    * local_data block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/dns_response_policy_rule#local_data DnsResponsePolicyRule#local_data}
    */
    readonly localData?: DnsResponsePolicyRuleLocalData;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/dns_response_policy_rule#timeouts DnsResponsePolicyRule#timeouts}
    */
    readonly timeouts?: DnsResponsePolicyRuleTimeouts;
}
export interface DnsResponsePolicyRuleLocalDataLocalDatas {
    /**
    * For example, www.example.com.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/dns_response_policy_rule#name DnsResponsePolicyRule#name}
    */
    readonly name: string;
    /**
    * As defined in RFC 1035 (section 5) and RFC 1034 (section 3.6.1)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/dns_response_policy_rule#rrdatas DnsResponsePolicyRule#rrdatas}
    */
    readonly rrdatas?: string[];
    /**
    * Number of seconds that this ResourceRecordSet can be cached by
  resolvers.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/dns_response_policy_rule#ttl DnsResponsePolicyRule#ttl}
    */
    readonly ttl?: number;
    /**
    * One of valid DNS resource types. Possible values: ["A", "AAAA", "CAA", "CNAME", "DNSKEY", "DS", "HTTPS", "IPSECVPNKEY", "MX", "NAPTR", "NS", "PTR", "SOA", "SPF", "SRV", "SSHFP", "SVCB", "TLSA", "TXT"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/dns_response_policy_rule#type DnsResponsePolicyRule#type}
    */
    readonly type: string;
}
export declare function dnsResponsePolicyRuleLocalDataLocalDatasToTerraform(struct?: DnsResponsePolicyRuleLocalDataLocalDatas | cdktf.IResolvable): any;
export declare class DnsResponsePolicyRuleLocalDataLocalDatasOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DnsResponsePolicyRuleLocalDataLocalDatas | cdktf.IResolvable | undefined;
    set internalValue(value: DnsResponsePolicyRuleLocalDataLocalDatas | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _rrdatas?;
    get rrdatas(): string[];
    set rrdatas(value: string[]);
    resetRrdatas(): void;
    get rrdatasInput(): string[] | undefined;
    private _ttl?;
    get ttl(): number;
    set ttl(value: number);
    resetTtl(): void;
    get ttlInput(): number | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
}
export declare class DnsResponsePolicyRuleLocalDataLocalDatasList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DnsResponsePolicyRuleLocalDataLocalDatas[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DnsResponsePolicyRuleLocalDataLocalDatasOutputReference;
}
export interface DnsResponsePolicyRuleLocalData {
    /**
    * local_datas block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/dns_response_policy_rule#local_datas DnsResponsePolicyRule#local_datas}
    */
    readonly localDatas: DnsResponsePolicyRuleLocalDataLocalDatas[] | cdktf.IResolvable;
}
export declare function dnsResponsePolicyRuleLocalDataToTerraform(struct?: DnsResponsePolicyRuleLocalDataOutputReference | DnsResponsePolicyRuleLocalData): any;
export declare class DnsResponsePolicyRuleLocalDataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DnsResponsePolicyRuleLocalData | undefined;
    set internalValue(value: DnsResponsePolicyRuleLocalData | undefined);
    private _localDatas;
    get localDatas(): DnsResponsePolicyRuleLocalDataLocalDatasList;
    putLocalDatas(value: DnsResponsePolicyRuleLocalDataLocalDatas[] | cdktf.IResolvable): void;
    get localDatasInput(): cdktf.IResolvable | DnsResponsePolicyRuleLocalDataLocalDatas[] | undefined;
}
export interface DnsResponsePolicyRuleTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/dns_response_policy_rule#create DnsResponsePolicyRule#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/dns_response_policy_rule#delete DnsResponsePolicyRule#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/dns_response_policy_rule#update DnsResponsePolicyRule#update}
    */
    readonly update?: string;
}
export declare function dnsResponsePolicyRuleTimeoutsToTerraform(struct?: DnsResponsePolicyRuleTimeouts | cdktf.IResolvable): any;
export declare class DnsResponsePolicyRuleTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DnsResponsePolicyRuleTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: DnsResponsePolicyRuleTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/dns_response_policy_rule google_dns_response_policy_rule}
*/
export declare class DnsResponsePolicyRule extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_dns_response_policy_rule";
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/dns_response_policy_rule google_dns_response_policy_rule} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DnsResponsePolicyRuleConfig
    */
    constructor(scope: Construct, id: string, config: DnsResponsePolicyRuleConfig);
    private _dnsName?;
    get dnsName(): string;
    set dnsName(value: string);
    get dnsNameInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _responsePolicy?;
    get responsePolicy(): string;
    set responsePolicy(value: string);
    get responsePolicyInput(): string | undefined;
    private _ruleName?;
    get ruleName(): string;
    set ruleName(value: string);
    get ruleNameInput(): string | undefined;
    private _localData;
    get localData(): DnsResponsePolicyRuleLocalDataOutputReference;
    putLocalData(value: DnsResponsePolicyRuleLocalData): void;
    resetLocalData(): void;
    get localDataInput(): DnsResponsePolicyRuleLocalData | undefined;
    private _timeouts;
    get timeouts(): DnsResponsePolicyRuleTimeoutsOutputReference;
    putTimeouts(value: DnsResponsePolicyRuleTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | DnsResponsePolicyRuleTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
