/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DocumentAiWarehouseDocumentSchemaConfig extends cdktf.TerraformMetaArguments {
    /**
    * Name of the schema given by the user.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#display_name DocumentAiWarehouseDocumentSchema#display_name}
    */
    readonly displayName: string;
    /**
    * Tells whether the document is a folder or a typical document.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#document_is_folder DocumentAiWarehouseDocumentSchema#document_is_folder}
    */
    readonly documentIsFolder?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#id DocumentAiWarehouseDocumentSchema#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The location of the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#location DocumentAiWarehouseDocumentSchema#location}
    */
    readonly location: string;
    /**
    * The unique identifier of the project.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#project_number DocumentAiWarehouseDocumentSchema#project_number}
    */
    readonly projectNumber: string;
    /**
    * property_definitions block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#property_definitions DocumentAiWarehouseDocumentSchema#property_definitions}
    */
    readonly propertyDefinitions: DocumentAiWarehouseDocumentSchemaPropertyDefinitions[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#timeouts DocumentAiWarehouseDocumentSchema#timeouts}
    */
    readonly timeouts?: DocumentAiWarehouseDocumentSchemaTimeouts;
}
export interface DocumentAiWarehouseDocumentSchemaPropertyDefinitionsDateTimeTypeOptions {
}
export declare function documentAiWarehouseDocumentSchemaPropertyDefinitionsDateTimeTypeOptionsToTerraform(struct?: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsDateTimeTypeOptionsOutputReference | DocumentAiWarehouseDocumentSchemaPropertyDefinitionsDateTimeTypeOptions): any;
export declare class DocumentAiWarehouseDocumentSchemaPropertyDefinitionsDateTimeTypeOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsDateTimeTypeOptions | undefined;
    set internalValue(value: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsDateTimeTypeOptions | undefined);
}
export interface DocumentAiWarehouseDocumentSchemaPropertyDefinitionsEnumTypeOptions {
    /**
    * List of possible enum values.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#possible_values DocumentAiWarehouseDocumentSchema#possible_values}
    */
    readonly possibleValues: string[];
    /**
    * Make sure the enum property value provided in the document is in the possile value list during document creation. The validation check runs by default.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#validation_check_disabled DocumentAiWarehouseDocumentSchema#validation_check_disabled}
    */
    readonly validationCheckDisabled?: boolean | cdktf.IResolvable;
}
export declare function documentAiWarehouseDocumentSchemaPropertyDefinitionsEnumTypeOptionsToTerraform(struct?: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsEnumTypeOptionsOutputReference | DocumentAiWarehouseDocumentSchemaPropertyDefinitionsEnumTypeOptions): any;
export declare class DocumentAiWarehouseDocumentSchemaPropertyDefinitionsEnumTypeOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsEnumTypeOptions | undefined;
    set internalValue(value: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsEnumTypeOptions | undefined);
    private _possibleValues?;
    get possibleValues(): string[];
    set possibleValues(value: string[]);
    get possibleValuesInput(): string[] | undefined;
    private _validationCheckDisabled?;
    get validationCheckDisabled(): boolean | cdktf.IResolvable;
    set validationCheckDisabled(value: boolean | cdktf.IResolvable);
    resetValidationCheckDisabled(): void;
    get validationCheckDisabledInput(): boolean | cdktf.IResolvable | undefined;
}
export interface DocumentAiWarehouseDocumentSchemaPropertyDefinitionsFloatTypeOptions {
}
export declare function documentAiWarehouseDocumentSchemaPropertyDefinitionsFloatTypeOptionsToTerraform(struct?: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsFloatTypeOptionsOutputReference | DocumentAiWarehouseDocumentSchemaPropertyDefinitionsFloatTypeOptions): any;
export declare class DocumentAiWarehouseDocumentSchemaPropertyDefinitionsFloatTypeOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsFloatTypeOptions | undefined;
    set internalValue(value: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsFloatTypeOptions | undefined);
}
export interface DocumentAiWarehouseDocumentSchemaPropertyDefinitionsIntegerTypeOptions {
}
export declare function documentAiWarehouseDocumentSchemaPropertyDefinitionsIntegerTypeOptionsToTerraform(struct?: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsIntegerTypeOptionsOutputReference | DocumentAiWarehouseDocumentSchemaPropertyDefinitionsIntegerTypeOptions): any;
export declare class DocumentAiWarehouseDocumentSchemaPropertyDefinitionsIntegerTypeOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsIntegerTypeOptions | undefined;
    set internalValue(value: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsIntegerTypeOptions | undefined);
}
export interface DocumentAiWarehouseDocumentSchemaPropertyDefinitionsMapTypeOptions {
}
export declare function documentAiWarehouseDocumentSchemaPropertyDefinitionsMapTypeOptionsToTerraform(struct?: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsMapTypeOptionsOutputReference | DocumentAiWarehouseDocumentSchemaPropertyDefinitionsMapTypeOptions): any;
export declare class DocumentAiWarehouseDocumentSchemaPropertyDefinitionsMapTypeOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsMapTypeOptions | undefined;
    set internalValue(value: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsMapTypeOptions | undefined);
}
export interface DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsDateTimeTypeOptions {
}
export declare function documentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsDateTimeTypeOptionsToTerraform(struct?: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsDateTimeTypeOptionsOutputReference | DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsDateTimeTypeOptions): any;
export declare class DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsDateTimeTypeOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsDateTimeTypeOptions | undefined;
    set internalValue(value: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsDateTimeTypeOptions | undefined);
}
export interface DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsEnumTypeOptions {
    /**
    * List of possible enum values.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#possible_values DocumentAiWarehouseDocumentSchema#possible_values}
    */
    readonly possibleValues: string[];
    /**
    * Make sure the enum property value provided in the document is in the possile value list during document creation. The validation check runs by default.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#validation_check_disabled DocumentAiWarehouseDocumentSchema#validation_check_disabled}
    */
    readonly validationCheckDisabled?: boolean | cdktf.IResolvable;
}
export declare function documentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsEnumTypeOptionsToTerraform(struct?: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsEnumTypeOptionsOutputReference | DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsEnumTypeOptions): any;
export declare class DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsEnumTypeOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsEnumTypeOptions | undefined;
    set internalValue(value: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsEnumTypeOptions | undefined);
    private _possibleValues?;
    get possibleValues(): string[];
    set possibleValues(value: string[]);
    get possibleValuesInput(): string[] | undefined;
    private _validationCheckDisabled?;
    get validationCheckDisabled(): boolean | cdktf.IResolvable;
    set validationCheckDisabled(value: boolean | cdktf.IResolvable);
    resetValidationCheckDisabled(): void;
    get validationCheckDisabledInput(): boolean | cdktf.IResolvable | undefined;
}
export interface DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsFloatTypeOptions {
}
export declare function documentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsFloatTypeOptionsToTerraform(struct?: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsFloatTypeOptionsOutputReference | DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsFloatTypeOptions): any;
export declare class DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsFloatTypeOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsFloatTypeOptions | undefined;
    set internalValue(value: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsFloatTypeOptions | undefined);
}
export interface DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsIntegerTypeOptions {
}
export declare function documentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsIntegerTypeOptionsToTerraform(struct?: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsIntegerTypeOptionsOutputReference | DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsIntegerTypeOptions): any;
export declare class DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsIntegerTypeOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsIntegerTypeOptions | undefined;
    set internalValue(value: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsIntegerTypeOptions | undefined);
}
export interface DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsMapTypeOptions {
}
export declare function documentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsMapTypeOptionsToTerraform(struct?: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsMapTypeOptionsOutputReference | DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsMapTypeOptions): any;
export declare class DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsMapTypeOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsMapTypeOptions | undefined;
    set internalValue(value: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsMapTypeOptions | undefined);
}
export interface DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsSchemaSources {
    /**
    * The schema name in the source.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#name DocumentAiWarehouseDocumentSchema#name}
    */
    readonly name?: string;
    /**
    * The Doc AI processor type name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#processor_type DocumentAiWarehouseDocumentSchema#processor_type}
    */
    readonly processorType?: string;
}
export declare function documentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsSchemaSourcesToTerraform(struct?: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsSchemaSources | cdktf.IResolvable): any;
export declare class DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsSchemaSourcesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsSchemaSources | cdktf.IResolvable | undefined;
    set internalValue(value: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsSchemaSources | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _processorType?;
    get processorType(): string;
    set processorType(value: string);
    resetProcessorType(): void;
    get processorTypeInput(): string | undefined;
}
export declare class DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsSchemaSourcesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsSchemaSources[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsSchemaSourcesOutputReference;
}
export interface DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsTextTypeOptions {
}
export declare function documentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsTextTypeOptionsToTerraform(struct?: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsTextTypeOptionsOutputReference | DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsTextTypeOptions): any;
export declare class DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsTextTypeOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsTextTypeOptions | undefined;
    set internalValue(value: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsTextTypeOptions | undefined);
}
export interface DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsTimestampTypeOptions {
}
export declare function documentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsTimestampTypeOptionsToTerraform(struct?: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsTimestampTypeOptionsOutputReference | DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsTimestampTypeOptions): any;
export declare class DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsTimestampTypeOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsTimestampTypeOptions | undefined;
    set internalValue(value: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsTimestampTypeOptions | undefined);
}
export interface DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitions {
    /**
    * The display-name for the property, used for front-end.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#display_name DocumentAiWarehouseDocumentSchema#display_name}
    */
    readonly displayName?: string;
    /**
    * Whether the property can be filtered. If this is a sub-property, all the parent properties must be marked filterable.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#is_filterable DocumentAiWarehouseDocumentSchema#is_filterable}
    */
    readonly isFilterable?: boolean | cdktf.IResolvable;
    /**
    * Whether the property is user supplied metadata.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#is_metadata DocumentAiWarehouseDocumentSchema#is_metadata}
    */
    readonly isMetadata?: boolean | cdktf.IResolvable;
    /**
    * Whether the property can have multiple values.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#is_repeatable DocumentAiWarehouseDocumentSchema#is_repeatable}
    */
    readonly isRepeatable?: boolean | cdktf.IResolvable;
    /**
    * Whether the property is mandatory.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#is_required DocumentAiWarehouseDocumentSchema#is_required}
    */
    readonly isRequired?: boolean | cdktf.IResolvable;
    /**
    * Indicates that the property should be included in a global search.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#is_searchable DocumentAiWarehouseDocumentSchema#is_searchable}
    */
    readonly isSearchable?: boolean | cdktf.IResolvable;
    /**
    * The name of the metadata property.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#name DocumentAiWarehouseDocumentSchema#name}
    */
    readonly name: string;
    /**
    * Stores the retrieval importance. Possible values: ["HIGHEST", "HIGHER", "HIGH", "MEDIUM", "LOW", "LOWEST"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#retrieval_importance DocumentAiWarehouseDocumentSchema#retrieval_importance}
    */
    readonly retrievalImportance?: string;
    /**
    * date_time_type_options block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#date_time_type_options DocumentAiWarehouseDocumentSchema#date_time_type_options}
    */
    readonly dateTimeTypeOptions?: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsDateTimeTypeOptions;
    /**
    * enum_type_options block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#enum_type_options DocumentAiWarehouseDocumentSchema#enum_type_options}
    */
    readonly enumTypeOptions?: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsEnumTypeOptions;
    /**
    * float_type_options block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#float_type_options DocumentAiWarehouseDocumentSchema#float_type_options}
    */
    readonly floatTypeOptions?: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsFloatTypeOptions;
    /**
    * integer_type_options block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#integer_type_options DocumentAiWarehouseDocumentSchema#integer_type_options}
    */
    readonly integerTypeOptions?: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsIntegerTypeOptions;
    /**
    * map_type_options block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#map_type_options DocumentAiWarehouseDocumentSchema#map_type_options}
    */
    readonly mapTypeOptions?: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsMapTypeOptions;
    /**
    * schema_sources block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#schema_sources DocumentAiWarehouseDocumentSchema#schema_sources}
    */
    readonly schemaSources?: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsSchemaSources[] | cdktf.IResolvable;
    /**
    * text_type_options block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#text_type_options DocumentAiWarehouseDocumentSchema#text_type_options}
    */
    readonly textTypeOptions?: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsTextTypeOptions;
    /**
    * timestamp_type_options block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#timestamp_type_options DocumentAiWarehouseDocumentSchema#timestamp_type_options}
    */
    readonly timestampTypeOptions?: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsTimestampTypeOptions;
}
export declare function documentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsToTerraform(struct?: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitions | cdktf.IResolvable): any;
export declare class DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitions | cdktf.IResolvable | undefined;
    set internalValue(value: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitions | cdktf.IResolvable | undefined);
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    private _isFilterable?;
    get isFilterable(): boolean | cdktf.IResolvable;
    set isFilterable(value: boolean | cdktf.IResolvable);
    resetIsFilterable(): void;
    get isFilterableInput(): boolean | cdktf.IResolvable | undefined;
    private _isMetadata?;
    get isMetadata(): boolean | cdktf.IResolvable;
    set isMetadata(value: boolean | cdktf.IResolvable);
    resetIsMetadata(): void;
    get isMetadataInput(): boolean | cdktf.IResolvable | undefined;
    private _isRepeatable?;
    get isRepeatable(): boolean | cdktf.IResolvable;
    set isRepeatable(value: boolean | cdktf.IResolvable);
    resetIsRepeatable(): void;
    get isRepeatableInput(): boolean | cdktf.IResolvable | undefined;
    private _isRequired?;
    get isRequired(): boolean | cdktf.IResolvable;
    set isRequired(value: boolean | cdktf.IResolvable);
    resetIsRequired(): void;
    get isRequiredInput(): boolean | cdktf.IResolvable | undefined;
    private _isSearchable?;
    get isSearchable(): boolean | cdktf.IResolvable;
    set isSearchable(value: boolean | cdktf.IResolvable);
    resetIsSearchable(): void;
    get isSearchableInput(): boolean | cdktf.IResolvable | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _retrievalImportance?;
    get retrievalImportance(): string;
    set retrievalImportance(value: string);
    resetRetrievalImportance(): void;
    get retrievalImportanceInput(): string | undefined;
    private _dateTimeTypeOptions;
    get dateTimeTypeOptions(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsDateTimeTypeOptionsOutputReference;
    putDateTimeTypeOptions(value: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsDateTimeTypeOptions): void;
    resetDateTimeTypeOptions(): void;
    get dateTimeTypeOptionsInput(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsDateTimeTypeOptions | undefined;
    private _enumTypeOptions;
    get enumTypeOptions(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsEnumTypeOptionsOutputReference;
    putEnumTypeOptions(value: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsEnumTypeOptions): void;
    resetEnumTypeOptions(): void;
    get enumTypeOptionsInput(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsEnumTypeOptions | undefined;
    private _floatTypeOptions;
    get floatTypeOptions(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsFloatTypeOptionsOutputReference;
    putFloatTypeOptions(value: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsFloatTypeOptions): void;
    resetFloatTypeOptions(): void;
    get floatTypeOptionsInput(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsFloatTypeOptions | undefined;
    private _integerTypeOptions;
    get integerTypeOptions(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsIntegerTypeOptionsOutputReference;
    putIntegerTypeOptions(value: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsIntegerTypeOptions): void;
    resetIntegerTypeOptions(): void;
    get integerTypeOptionsInput(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsIntegerTypeOptions | undefined;
    private _mapTypeOptions;
    get mapTypeOptions(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsMapTypeOptionsOutputReference;
    putMapTypeOptions(value: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsMapTypeOptions): void;
    resetMapTypeOptions(): void;
    get mapTypeOptionsInput(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsMapTypeOptions | undefined;
    private _schemaSources;
    get schemaSources(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsSchemaSourcesList;
    putSchemaSources(value: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsSchemaSources[] | cdktf.IResolvable): void;
    resetSchemaSources(): void;
    get schemaSourcesInput(): cdktf.IResolvable | DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsSchemaSources[] | undefined;
    private _textTypeOptions;
    get textTypeOptions(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsTextTypeOptionsOutputReference;
    putTextTypeOptions(value: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsTextTypeOptions): void;
    resetTextTypeOptions(): void;
    get textTypeOptionsInput(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsTextTypeOptions | undefined;
    private _timestampTypeOptions;
    get timestampTypeOptions(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsTimestampTypeOptionsOutputReference;
    putTimestampTypeOptions(value: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsTimestampTypeOptions): void;
    resetTimestampTypeOptions(): void;
    get timestampTypeOptionsInput(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsTimestampTypeOptions | undefined;
}
export declare class DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitions[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsOutputReference;
}
export interface DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptions {
    /**
    * property_definitions block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#property_definitions DocumentAiWarehouseDocumentSchema#property_definitions}
    */
    readonly propertyDefinitions: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitions[] | cdktf.IResolvable;
}
export declare function documentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsToTerraform(struct?: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsOutputReference | DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptions): any;
export declare class DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptions | undefined;
    set internalValue(value: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptions | undefined);
    private _propertyDefinitions;
    get propertyDefinitions(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsList;
    putPropertyDefinitions(value: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitions[] | cdktf.IResolvable): void;
    get propertyDefinitionsInput(): cdktf.IResolvable | DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitions[] | undefined;
}
export interface DocumentAiWarehouseDocumentSchemaPropertyDefinitionsSchemaSources {
    /**
    * The schema name in the source.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#name DocumentAiWarehouseDocumentSchema#name}
    */
    readonly name?: string;
    /**
    * The Doc AI processor type name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#processor_type DocumentAiWarehouseDocumentSchema#processor_type}
    */
    readonly processorType?: string;
}
export declare function documentAiWarehouseDocumentSchemaPropertyDefinitionsSchemaSourcesToTerraform(struct?: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsSchemaSources | cdktf.IResolvable): any;
export declare class DocumentAiWarehouseDocumentSchemaPropertyDefinitionsSchemaSourcesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsSchemaSources | cdktf.IResolvable | undefined;
    set internalValue(value: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsSchemaSources | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _processorType?;
    get processorType(): string;
    set processorType(value: string);
    resetProcessorType(): void;
    get processorTypeInput(): string | undefined;
}
export declare class DocumentAiWarehouseDocumentSchemaPropertyDefinitionsSchemaSourcesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsSchemaSources[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsSchemaSourcesOutputReference;
}
export interface DocumentAiWarehouseDocumentSchemaPropertyDefinitionsTextTypeOptions {
}
export declare function documentAiWarehouseDocumentSchemaPropertyDefinitionsTextTypeOptionsToTerraform(struct?: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsTextTypeOptionsOutputReference | DocumentAiWarehouseDocumentSchemaPropertyDefinitionsTextTypeOptions): any;
export declare class DocumentAiWarehouseDocumentSchemaPropertyDefinitionsTextTypeOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsTextTypeOptions | undefined;
    set internalValue(value: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsTextTypeOptions | undefined);
}
export interface DocumentAiWarehouseDocumentSchemaPropertyDefinitionsTimestampTypeOptions {
}
export declare function documentAiWarehouseDocumentSchemaPropertyDefinitionsTimestampTypeOptionsToTerraform(struct?: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsTimestampTypeOptionsOutputReference | DocumentAiWarehouseDocumentSchemaPropertyDefinitionsTimestampTypeOptions): any;
export declare class DocumentAiWarehouseDocumentSchemaPropertyDefinitionsTimestampTypeOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsTimestampTypeOptions | undefined;
    set internalValue(value: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsTimestampTypeOptions | undefined);
}
export interface DocumentAiWarehouseDocumentSchemaPropertyDefinitions {
    /**
    * The display-name for the property, used for front-end.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#display_name DocumentAiWarehouseDocumentSchema#display_name}
    */
    readonly displayName?: string;
    /**
    * Whether the property can be filtered. If this is a sub-property, all the parent properties must be marked filterable.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#is_filterable DocumentAiWarehouseDocumentSchema#is_filterable}
    */
    readonly isFilterable?: boolean | cdktf.IResolvable;
    /**
    * Whether the property is user supplied metadata.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#is_metadata DocumentAiWarehouseDocumentSchema#is_metadata}
    */
    readonly isMetadata?: boolean | cdktf.IResolvable;
    /**
    * Whether the property can have multiple values.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#is_repeatable DocumentAiWarehouseDocumentSchema#is_repeatable}
    */
    readonly isRepeatable?: boolean | cdktf.IResolvable;
    /**
    * Whether the property is mandatory.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#is_required DocumentAiWarehouseDocumentSchema#is_required}
    */
    readonly isRequired?: boolean | cdktf.IResolvable;
    /**
    * Indicates that the property should be included in a global search.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#is_searchable DocumentAiWarehouseDocumentSchema#is_searchable}
    */
    readonly isSearchable?: boolean | cdktf.IResolvable;
    /**
    * The name of the metadata property.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#name DocumentAiWarehouseDocumentSchema#name}
    */
    readonly name: string;
    /**
    * Stores the retrieval importance. Possible values: ["HIGHEST", "HIGHER", "HIGH", "MEDIUM", "LOW", "LOWEST"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#retrieval_importance DocumentAiWarehouseDocumentSchema#retrieval_importance}
    */
    readonly retrievalImportance?: string;
    /**
    * date_time_type_options block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#date_time_type_options DocumentAiWarehouseDocumentSchema#date_time_type_options}
    */
    readonly dateTimeTypeOptions?: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsDateTimeTypeOptions;
    /**
    * enum_type_options block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#enum_type_options DocumentAiWarehouseDocumentSchema#enum_type_options}
    */
    readonly enumTypeOptions?: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsEnumTypeOptions;
    /**
    * float_type_options block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#float_type_options DocumentAiWarehouseDocumentSchema#float_type_options}
    */
    readonly floatTypeOptions?: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsFloatTypeOptions;
    /**
    * integer_type_options block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#integer_type_options DocumentAiWarehouseDocumentSchema#integer_type_options}
    */
    readonly integerTypeOptions?: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsIntegerTypeOptions;
    /**
    * map_type_options block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#map_type_options DocumentAiWarehouseDocumentSchema#map_type_options}
    */
    readonly mapTypeOptions?: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsMapTypeOptions;
    /**
    * property_type_options block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#property_type_options DocumentAiWarehouseDocumentSchema#property_type_options}
    */
    readonly propertyTypeOptions?: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptions;
    /**
    * schema_sources block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#schema_sources DocumentAiWarehouseDocumentSchema#schema_sources}
    */
    readonly schemaSources?: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsSchemaSources[] | cdktf.IResolvable;
    /**
    * text_type_options block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#text_type_options DocumentAiWarehouseDocumentSchema#text_type_options}
    */
    readonly textTypeOptions?: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsTextTypeOptions;
    /**
    * timestamp_type_options block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#timestamp_type_options DocumentAiWarehouseDocumentSchema#timestamp_type_options}
    */
    readonly timestampTypeOptions?: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsTimestampTypeOptions;
}
export declare function documentAiWarehouseDocumentSchemaPropertyDefinitionsToTerraform(struct?: DocumentAiWarehouseDocumentSchemaPropertyDefinitions | cdktf.IResolvable): any;
export declare class DocumentAiWarehouseDocumentSchemaPropertyDefinitionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DocumentAiWarehouseDocumentSchemaPropertyDefinitions | cdktf.IResolvable | undefined;
    set internalValue(value: DocumentAiWarehouseDocumentSchemaPropertyDefinitions | cdktf.IResolvable | undefined);
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    private _isFilterable?;
    get isFilterable(): boolean | cdktf.IResolvable;
    set isFilterable(value: boolean | cdktf.IResolvable);
    resetIsFilterable(): void;
    get isFilterableInput(): boolean | cdktf.IResolvable | undefined;
    private _isMetadata?;
    get isMetadata(): boolean | cdktf.IResolvable;
    set isMetadata(value: boolean | cdktf.IResolvable);
    resetIsMetadata(): void;
    get isMetadataInput(): boolean | cdktf.IResolvable | undefined;
    private _isRepeatable?;
    get isRepeatable(): boolean | cdktf.IResolvable;
    set isRepeatable(value: boolean | cdktf.IResolvable);
    resetIsRepeatable(): void;
    get isRepeatableInput(): boolean | cdktf.IResolvable | undefined;
    private _isRequired?;
    get isRequired(): boolean | cdktf.IResolvable;
    set isRequired(value: boolean | cdktf.IResolvable);
    resetIsRequired(): void;
    get isRequiredInput(): boolean | cdktf.IResolvable | undefined;
    private _isSearchable?;
    get isSearchable(): boolean | cdktf.IResolvable;
    set isSearchable(value: boolean | cdktf.IResolvable);
    resetIsSearchable(): void;
    get isSearchableInput(): boolean | cdktf.IResolvable | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _retrievalImportance?;
    get retrievalImportance(): string;
    set retrievalImportance(value: string);
    resetRetrievalImportance(): void;
    get retrievalImportanceInput(): string | undefined;
    private _dateTimeTypeOptions;
    get dateTimeTypeOptions(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsDateTimeTypeOptionsOutputReference;
    putDateTimeTypeOptions(value: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsDateTimeTypeOptions): void;
    resetDateTimeTypeOptions(): void;
    get dateTimeTypeOptionsInput(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsDateTimeTypeOptions | undefined;
    private _enumTypeOptions;
    get enumTypeOptions(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsEnumTypeOptionsOutputReference;
    putEnumTypeOptions(value: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsEnumTypeOptions): void;
    resetEnumTypeOptions(): void;
    get enumTypeOptionsInput(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsEnumTypeOptions | undefined;
    private _floatTypeOptions;
    get floatTypeOptions(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsFloatTypeOptionsOutputReference;
    putFloatTypeOptions(value: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsFloatTypeOptions): void;
    resetFloatTypeOptions(): void;
    get floatTypeOptionsInput(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsFloatTypeOptions | undefined;
    private _integerTypeOptions;
    get integerTypeOptions(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsIntegerTypeOptionsOutputReference;
    putIntegerTypeOptions(value: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsIntegerTypeOptions): void;
    resetIntegerTypeOptions(): void;
    get integerTypeOptionsInput(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsIntegerTypeOptions | undefined;
    private _mapTypeOptions;
    get mapTypeOptions(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsMapTypeOptionsOutputReference;
    putMapTypeOptions(value: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsMapTypeOptions): void;
    resetMapTypeOptions(): void;
    get mapTypeOptionsInput(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsMapTypeOptions | undefined;
    private _propertyTypeOptions;
    get propertyTypeOptions(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsOutputReference;
    putPropertyTypeOptions(value: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptions): void;
    resetPropertyTypeOptions(): void;
    get propertyTypeOptionsInput(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptions | undefined;
    private _schemaSources;
    get schemaSources(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsSchemaSourcesList;
    putSchemaSources(value: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsSchemaSources[] | cdktf.IResolvable): void;
    resetSchemaSources(): void;
    get schemaSourcesInput(): cdktf.IResolvable | DocumentAiWarehouseDocumentSchemaPropertyDefinitionsSchemaSources[] | undefined;
    private _textTypeOptions;
    get textTypeOptions(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsTextTypeOptionsOutputReference;
    putTextTypeOptions(value: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsTextTypeOptions): void;
    resetTextTypeOptions(): void;
    get textTypeOptionsInput(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsTextTypeOptions | undefined;
    private _timestampTypeOptions;
    get timestampTypeOptions(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsTimestampTypeOptionsOutputReference;
    putTimestampTypeOptions(value: DocumentAiWarehouseDocumentSchemaPropertyDefinitionsTimestampTypeOptions): void;
    resetTimestampTypeOptions(): void;
    get timestampTypeOptionsInput(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsTimestampTypeOptions | undefined;
}
export declare class DocumentAiWarehouseDocumentSchemaPropertyDefinitionsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DocumentAiWarehouseDocumentSchemaPropertyDefinitions[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsOutputReference;
}
export interface DocumentAiWarehouseDocumentSchemaTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#create DocumentAiWarehouseDocumentSchema#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema#delete DocumentAiWarehouseDocumentSchema#delete}
    */
    readonly delete?: string;
}
export declare function documentAiWarehouseDocumentSchemaTimeoutsToTerraform(struct?: DocumentAiWarehouseDocumentSchemaTimeouts | cdktf.IResolvable): any;
export declare class DocumentAiWarehouseDocumentSchemaTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DocumentAiWarehouseDocumentSchemaTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: DocumentAiWarehouseDocumentSchemaTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema google_document_ai_warehouse_document_schema}
*/
export declare class DocumentAiWarehouseDocumentSchema extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_document_ai_warehouse_document_schema";
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/document_ai_warehouse_document_schema google_document_ai_warehouse_document_schema} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DocumentAiWarehouseDocumentSchemaConfig
    */
    constructor(scope: Construct, id: string, config: DocumentAiWarehouseDocumentSchemaConfig);
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    get displayNameInput(): string | undefined;
    private _documentIsFolder?;
    get documentIsFolder(): boolean | cdktf.IResolvable;
    set documentIsFolder(value: boolean | cdktf.IResolvable);
    resetDocumentIsFolder(): void;
    get documentIsFolderInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    private _projectNumber?;
    get projectNumber(): string;
    set projectNumber(value: string);
    get projectNumberInput(): string | undefined;
    private _propertyDefinitions;
    get propertyDefinitions(): DocumentAiWarehouseDocumentSchemaPropertyDefinitionsList;
    putPropertyDefinitions(value: DocumentAiWarehouseDocumentSchemaPropertyDefinitions[] | cdktf.IResolvable): void;
    get propertyDefinitionsInput(): cdktf.IResolvable | DocumentAiWarehouseDocumentSchemaPropertyDefinitions[] | undefined;
    private _timeouts;
    get timeouts(): DocumentAiWarehouseDocumentSchemaTimeoutsOutputReference;
    putTimeouts(value: DocumentAiWarehouseDocumentSchemaTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | DocumentAiWarehouseDocumentSchemaTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
