/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface IdentityPlatformConfigConfig extends cdktf.TerraformMetaArguments {
    /**
    * List of domains authorized for OAuth redirects.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/identity_platform_config#authorized_domains IdentityPlatformConfig#authorized_domains}
    */
    readonly authorizedDomains?: string[];
    /**
    * Whether anonymous users will be auto-deleted after a period of 30 days
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/identity_platform_config#autodelete_anonymous_users IdentityPlatformConfig#autodelete_anonymous_users}
    */
    readonly autodeleteAnonymousUsers?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/identity_platform_config#id IdentityPlatformConfig#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/identity_platform_config#project IdentityPlatformConfig#project}
    */
    readonly project?: string;
    /**
    * blocking_functions block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/identity_platform_config#blocking_functions IdentityPlatformConfig#blocking_functions}
    */
    readonly blockingFunctions?: IdentityPlatformConfigBlockingFunctions;
    /**
    * quota block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/identity_platform_config#quota IdentityPlatformConfig#quota}
    */
    readonly quota?: IdentityPlatformConfigQuota;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/identity_platform_config#timeouts IdentityPlatformConfig#timeouts}
    */
    readonly timeouts?: IdentityPlatformConfigTimeouts;
}
export interface IdentityPlatformConfigBlockingFunctionsForwardInboundCredentials {
    /**
    * Whether to pass the user's OAuth identity provider's access token.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/identity_platform_config#access_token IdentityPlatformConfig#access_token}
    */
    readonly accessToken?: boolean | cdktf.IResolvable;
    /**
    * Whether to pass the user's OIDC identity provider's ID token.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/identity_platform_config#id_token IdentityPlatformConfig#id_token}
    */
    readonly idToken?: boolean | cdktf.IResolvable;
    /**
    * Whether to pass the user's OAuth identity provider's refresh token.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/identity_platform_config#refresh_token IdentityPlatformConfig#refresh_token}
    */
    readonly refreshToken?: boolean | cdktf.IResolvable;
}
export declare function identityPlatformConfigBlockingFunctionsForwardInboundCredentialsToTerraform(struct?: IdentityPlatformConfigBlockingFunctionsForwardInboundCredentialsOutputReference | IdentityPlatformConfigBlockingFunctionsForwardInboundCredentials): any;
export declare class IdentityPlatformConfigBlockingFunctionsForwardInboundCredentialsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IdentityPlatformConfigBlockingFunctionsForwardInboundCredentials | undefined;
    set internalValue(value: IdentityPlatformConfigBlockingFunctionsForwardInboundCredentials | undefined);
    private _accessToken?;
    get accessToken(): boolean | cdktf.IResolvable;
    set accessToken(value: boolean | cdktf.IResolvable);
    resetAccessToken(): void;
    get accessTokenInput(): boolean | cdktf.IResolvable | undefined;
    private _idToken?;
    get idToken(): boolean | cdktf.IResolvable;
    set idToken(value: boolean | cdktf.IResolvable);
    resetIdToken(): void;
    get idTokenInput(): boolean | cdktf.IResolvable | undefined;
    private _refreshToken?;
    get refreshToken(): boolean | cdktf.IResolvable;
    set refreshToken(value: boolean | cdktf.IResolvable);
    resetRefreshToken(): void;
    get refreshTokenInput(): boolean | cdktf.IResolvable | undefined;
}
export interface IdentityPlatformConfigBlockingFunctionsTriggers {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/identity_platform_config#event_type IdentityPlatformConfig#event_type}
    */
    readonly eventType: string;
    /**
    * HTTP URI trigger for the Cloud Function.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/identity_platform_config#function_uri IdentityPlatformConfig#function_uri}
    */
    readonly functionUri: string;
}
export declare function identityPlatformConfigBlockingFunctionsTriggersToTerraform(struct?: IdentityPlatformConfigBlockingFunctionsTriggers | cdktf.IResolvable): any;
export declare class IdentityPlatformConfigBlockingFunctionsTriggersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): IdentityPlatformConfigBlockingFunctionsTriggers | cdktf.IResolvable | undefined;
    set internalValue(value: IdentityPlatformConfigBlockingFunctionsTriggers | cdktf.IResolvable | undefined);
    private _eventType?;
    get eventType(): string;
    set eventType(value: string);
    get eventTypeInput(): string | undefined;
    private _functionUri?;
    get functionUri(): string;
    set functionUri(value: string);
    get functionUriInput(): string | undefined;
    get updateTime(): string;
}
export declare class IdentityPlatformConfigBlockingFunctionsTriggersList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: IdentityPlatformConfigBlockingFunctionsTriggers[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): IdentityPlatformConfigBlockingFunctionsTriggersOutputReference;
}
export interface IdentityPlatformConfigBlockingFunctions {
    /**
    * forward_inbound_credentials block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/identity_platform_config#forward_inbound_credentials IdentityPlatformConfig#forward_inbound_credentials}
    */
    readonly forwardInboundCredentials?: IdentityPlatformConfigBlockingFunctionsForwardInboundCredentials;
    /**
    * triggers block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/identity_platform_config#triggers IdentityPlatformConfig#triggers}
    */
    readonly triggers: IdentityPlatformConfigBlockingFunctionsTriggers[] | cdktf.IResolvable;
}
export declare function identityPlatformConfigBlockingFunctionsToTerraform(struct?: IdentityPlatformConfigBlockingFunctionsOutputReference | IdentityPlatformConfigBlockingFunctions): any;
export declare class IdentityPlatformConfigBlockingFunctionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IdentityPlatformConfigBlockingFunctions | undefined;
    set internalValue(value: IdentityPlatformConfigBlockingFunctions | undefined);
    private _forwardInboundCredentials;
    get forwardInboundCredentials(): IdentityPlatformConfigBlockingFunctionsForwardInboundCredentialsOutputReference;
    putForwardInboundCredentials(value: IdentityPlatformConfigBlockingFunctionsForwardInboundCredentials): void;
    resetForwardInboundCredentials(): void;
    get forwardInboundCredentialsInput(): IdentityPlatformConfigBlockingFunctionsForwardInboundCredentials | undefined;
    private _triggers;
    get triggers(): IdentityPlatformConfigBlockingFunctionsTriggersList;
    putTriggers(value: IdentityPlatformConfigBlockingFunctionsTriggers[] | cdktf.IResolvable): void;
    get triggersInput(): cdktf.IResolvable | IdentityPlatformConfigBlockingFunctionsTriggers[] | undefined;
}
export interface IdentityPlatformConfigQuotaSignUpQuotaConfig {
    /**
    * A sign up APIs quota that customers can override temporarily.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/identity_platform_config#quota IdentityPlatformConfig#quota}
    */
    readonly quota?: number;
    /**
    * How long this quota will be active for. It is measurred in seconds, e.g., Example: "9.615s".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/identity_platform_config#quota_duration IdentityPlatformConfig#quota_duration}
    */
    readonly quotaDuration?: string;
    /**
    * When this quota will take affect.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/identity_platform_config#start_time IdentityPlatformConfig#start_time}
    */
    readonly startTime?: string;
}
export declare function identityPlatformConfigQuotaSignUpQuotaConfigToTerraform(struct?: IdentityPlatformConfigQuotaSignUpQuotaConfigOutputReference | IdentityPlatformConfigQuotaSignUpQuotaConfig): any;
export declare class IdentityPlatformConfigQuotaSignUpQuotaConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IdentityPlatformConfigQuotaSignUpQuotaConfig | undefined;
    set internalValue(value: IdentityPlatformConfigQuotaSignUpQuotaConfig | undefined);
    private _quota?;
    get quota(): number;
    set quota(value: number);
    resetQuota(): void;
    get quotaInput(): number | undefined;
    private _quotaDuration?;
    get quotaDuration(): string;
    set quotaDuration(value: string);
    resetQuotaDuration(): void;
    get quotaDurationInput(): string | undefined;
    private _startTime?;
    get startTime(): string;
    set startTime(value: string);
    resetStartTime(): void;
    get startTimeInput(): string | undefined;
}
export interface IdentityPlatformConfigQuota {
    /**
    * sign_up_quota_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/identity_platform_config#sign_up_quota_config IdentityPlatformConfig#sign_up_quota_config}
    */
    readonly signUpQuotaConfig?: IdentityPlatformConfigQuotaSignUpQuotaConfig;
}
export declare function identityPlatformConfigQuotaToTerraform(struct?: IdentityPlatformConfigQuotaOutputReference | IdentityPlatformConfigQuota): any;
export declare class IdentityPlatformConfigQuotaOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IdentityPlatformConfigQuota | undefined;
    set internalValue(value: IdentityPlatformConfigQuota | undefined);
    private _signUpQuotaConfig;
    get signUpQuotaConfig(): IdentityPlatformConfigQuotaSignUpQuotaConfigOutputReference;
    putSignUpQuotaConfig(value: IdentityPlatformConfigQuotaSignUpQuotaConfig): void;
    resetSignUpQuotaConfig(): void;
    get signUpQuotaConfigInput(): IdentityPlatformConfigQuotaSignUpQuotaConfig | undefined;
}
export interface IdentityPlatformConfigTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/identity_platform_config#create IdentityPlatformConfig#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/identity_platform_config#delete IdentityPlatformConfig#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/identity_platform_config#update IdentityPlatformConfig#update}
    */
    readonly update?: string;
}
export declare function identityPlatformConfigTimeoutsToTerraform(struct?: IdentityPlatformConfigTimeouts | cdktf.IResolvable): any;
export declare class IdentityPlatformConfigTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IdentityPlatformConfigTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: IdentityPlatformConfigTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/identity_platform_config google_identity_platform_config}
*/
export declare class IdentityPlatformConfig extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_identity_platform_config";
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/4.78.0/docs/resources/identity_platform_config google_identity_platform_config} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options IdentityPlatformConfigConfig = {}
    */
    constructor(scope: Construct, id: string, config?: IdentityPlatformConfigConfig);
    private _authorizedDomains?;
    get authorizedDomains(): string[];
    set authorizedDomains(value: string[]);
    resetAuthorizedDomains(): void;
    get authorizedDomainsInput(): string[] | undefined;
    private _autodeleteAnonymousUsers?;
    get autodeleteAnonymousUsers(): boolean | cdktf.IResolvable;
    set autodeleteAnonymousUsers(value: boolean | cdktf.IResolvable);
    resetAutodeleteAnonymousUsers(): void;
    get autodeleteAnonymousUsersInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _blockingFunctions;
    get blockingFunctions(): IdentityPlatformConfigBlockingFunctionsOutputReference;
    putBlockingFunctions(value: IdentityPlatformConfigBlockingFunctions): void;
    resetBlockingFunctions(): void;
    get blockingFunctionsInput(): IdentityPlatformConfigBlockingFunctions | undefined;
    private _quota;
    get quota(): IdentityPlatformConfigQuotaOutputReference;
    putQuota(value: IdentityPlatformConfigQuota): void;
    resetQuota(): void;
    get quotaInput(): IdentityPlatformConfigQuota | undefined;
    private _timeouts;
    get timeouts(): IdentityPlatformConfigTimeoutsOutputReference;
    putTimeouts(value: IdentityPlatformConfigTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | IdentityPlatformConfigTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
